set more off, perm
version 12
clear
set type double

if "`c(username)'" == "jrichmond" {
	global root 	= "C:/Users/jrichmond/Favorites/Dropbox/TZ_Resource_Revenues/Poll"
}
global input "$root/Input"
global output "$root/Output"
global papers "$root/Papers"

*** Panel includes all samples
	use "$output/panel_160303", clear	
	drop if sample=="Moderators"
	replace weight = 1 if sample=="Elites"
	capture drop _*
	keep HHID weight z* t H* 
	drop H*0
	foreach var of global Hs{
		rename `var'1 `var'
	}
	

*** Two treatment groups each for citizens and elites - ignoring info + spillover group
	gen group = 1 if zdelib==1
	replace g = 0 if z==0
	replace g = 3 if zelite==0
	replace g = 4 if zelite==1
	drop if g==.

*** Keep only variables used in elite poll
	global Hs = "H11 H12 H13 H14 H15 H21 H22 H23 H24 H25 H26 H31 H32 H33 H34 H35 H36 H37 H38 H41 H42 H43 H44 H45 H46 H51 H52 H53 H61 H62 H63 H64 H65 H66 H67 H68 H69"
	global newHs = "H11 H25 H26 H36 H37 H45 H46 H51 H52"
	*global newHs = "H51"
	keep weight z* g $newHs

*** Create shorter value labels
	local H11min = "Generate electricity"
	local H11max = "Sell gas"
	local H25min = "Spend"
	local H25max = "Save"
	local H26min = "Borrow"
	local H26max = "Don't borrow"
	local H36min = "Gov't spending"
	local H36max = "Cash transfers"
	local H37min = "Against"
	local H37max = "For"
	local H45min = "Disagree"
	local H45max = "Agree"
	local H46min = "Infrastructure"
	local H46max = "Public services"
	local H51min = "Keep private"
	local H51max = "Publish"
	local H52min = "Gov't decides"
	local H52max = "Int'l oversight"

	local H11title = "Energy subsidies"
	local H25title = "Saving for the future"
	local H26title = "International borrowing"
	local H36title = "Cash transfers"
	local H37title = "Personal savings accounts"
	local H45title = "Waste in goverment spending"
	local H46title = "Infrastructure vs. services"
	local H51title = "Contract transparency"
	local H52title = "International oversight"
	
*** Create binary indicators
	foreach H of global newHs{
		sum `H'
		gen pro`H' = `H'>r(min) + (r(max)-r(min))/2
		gen con`H' = `H'<r(max) - (r(max)-r(min))/2
		gen neu`H' = `H'==r(max) - (r(max)-r(min))/2
	}


*** Reshape to bring in labels
	collapse (mean) pro* con* neu* [w=weight], by(g)
	reshape long pro con neu, i(g) j(H) string
	order H g
	sort  H g

*** Graph preferences
	global fontsize = "medium"
	*do "/Mac/Macros/JCS Graph Colors.do"
	*mycolors white
	global legendpos = 6
	global char = 75

*** Cosmetic
	gen 	sample = 1 if g<2
	replace sample = 2 if g>2
	label define sample 1 "Voters" 2 "Elites"
	label define groups 0 "Without deliberating" 1 "After deliberating"	///
						3 "Without seeing poll results" 4 "After seeing poll results"
	label values group groups
	label values sample sample
	*** Really silly thing to make sure rounded shares add to 100 exactly
	gen temppro = .
	gen tempneu = .
	gen tempcon = .
	gen adj = .
	forval i = 1/10{
		foreach var in pro neu con{
			replace	`var' = `var' - adj/1000 if adj!=.
			replace temp`var' = round(`var'*100,1)	
		}
		replace adj = temppro + tempneu + tempcon - 100
	}
	foreach var in pro neu con{
		replace `var' = round(`var'*100,1)
	}

	*pause on
	
	foreach H of global newHs{
		preserve
			use "$output/survey qx 150609.dta", clear
			replace Varname = subinstr(Varname,"_","",.)
			keep if Varname=="`H'"
			*** Shortening question stem:
				replace Question = "Some people think Tanzanians should pay the full price for energy to collect as much money as possible. Other people think the gas should be used mostly to produce cheap electricity. What do you think?" if Varname=="H11"
				replace Question = "Some people think the money should be saved mostly for the future. Other people think that the money should be spent now. What do you think?" if Varname=="H25"
				replace Question = "Tanzania should use the expected money from gas to borrow money from overseas and start spending sooner..." if Varname=="H26"
				replace Question = "Some people think that the money should be given directly to households. Other people think that the money should be spent by the government for what the public needs. What do you think?" if Varname=="H36"
				replace Question = "What if some money is put into a savings account for every child at birth with each child havingaccess to the resulting money at age 18?" if Varname=="H37"
				replace Question = "When the government increases spending on roads and schools a lot of money is wasted. Do you:" if Varname=="H45"
				replace Question = "Some people think the money should be spent by the government on building things the people need, such as roads or the electricity system... Other people think the money should be spent on improving public services such as health care and education. What do you think?" if Varname=="H46"
				replace Question = "Some people think the government should be able to keep contracts private. Other people think  all oil and gas contracts should be published for citizens to access them. What do you think?" if Varname=="H51"
				replace Question = "Some think the government should decide how to spend most of the money. Others think most of the money should be managed by an international group of experts. What do you think?" if Varname=="H52"
				*** Raymond Guiteras' code to wrap notes	
				local MyNote = Question
				local l = length("`MyNote'")
				local b = ceil(`l'/$char)
				if `l' > $char {
					forv i = 1/`b' { 
						local lab`i': piece `i' $char of "`MyNote'", nobreak
						if `i'==1 {
							local MyNote2 `""`lab`i''""'
						}
						if `i'>=2 {
							local MyNote2 `"`MyNote2' "`lab`i''""'
						}
					}
				}
				else {
					local MyNote2 `""`MyNote'""'
				}
		restore

		graph 	hbar con neu pro if H=="`H'", stack							///
				blabel(bar, pos(center) color(white) size(medium))			///
				bar(1, color("0 107 119")) 										///
				bar(2, color(gs12)) 										///
				bar(3, color("255 187 54")) 										///
				over(group, axis(noline)) over(sample) nofill				///
				$myregion	aspect(1)										///
				ysc(noline) ylabel(, nogrid notick nolabel) 			 	///
				ytitle("% of respondents")									///
				legend(order(1 "``H'min'" 2 "Neutral" 3 "``H'max'") stack row(1) region(style(none)) pos(1))	///
				subtitle(`MyNote2', color($cf) size($fontsize) justification(left) margin(small) span bexpand)	///				
				title("``H'title'", color($cf) size() justification(left) margin(small) span bexpand)					
				gr export "$papers/figures/elite_`H'.pdf", as(pdf) replace	
		*pause
	}
	
export excel using "$output/final results_JR.xlsx", first(var) replace 
export excel using "$output/final results_JR.csv", first(var) replace 
	
exit

