use "$output/panel.dta", clear
	capture drop _*
	
*** Three treatment groups - ignoring spillover group
	gen 	g = 1 if zinfo==1
	replace g = 2 if zdelib==1
	replace g = 0 if z==0

*** Graph quirk: can't have 0/1, need 1/2 for binary response
	forval n = 1/9{
		forval t = 0/1{
			replace H6`n'`t' 	= H6`n'`t' + 1
			replace H6`n'`t' 	= 1 if H6`n'`t'!=2
		}
	}

*** Reshape to use tsline
	/*
	keep HHID g t H* 
	reshape long  	H11  H22  H25  H32  H35  H38  H43  H46  H53  H63  H66  H69  H15 	///
				  	H12  H23  H26  H33  H36  H41  H44  H51  H61  H64  H67  H13			///
					H21  H24  H31  H34  H37  H42  H45  H52  H62  H65  H68  H14,			///
					i(HHID) j(t)
	*/
	keep HHID H11* H25* H31* H62* g t
	reshape long H11  H25  H31  H62, i(HHID) j(t)


*** Undoing recoding
	foreach H of varlist H11 H25 {								
		labrecode `H' (1=7)(2=6)(3=5)(5=3)(6=2)(7=1)(105=.)(107=.)(-99=.), nostrict	
	}

	preserve
		collapse (mean) H*, by(g t)
		tempfile means
		save `means'
	restore
	preserve
		collapse (semean) H*, by(g t)
		tempfile se
		rename H* seH*
		save `se'
	restore
	collapse (max) H* , by(g t)
	rename H* maxH*
	mmerge g t using `means'
	mmerge g t using `se'
	foreach var of varlist maxH*{
		replace `var' = `var' + 1 if `var'==10
	}
	sort 	g t
	tsset 	g t
	
*** Create confidence intervals
	foreach var of varlist H*{
		gen lo`var' = `var' - 1.96*se`var'
		gen hi`var' = `var' + 1.96*se`var'
	}

*** Graph preferences
	global fontsize = "medium"
	do "$dofiles/X graph colors.do"
	mycolors white
	global legendpos = 6
	global char = 55

tokenize 1 5 1 2
local j = 1
foreach m in 1 2 3 6{
	local n = ``j''
		preserve
			use "$output/survey qx 150609.dta", clear
			keep if Varname=="H`m'_`n'"
			local most = Maximum
			local least = Minimum
			local middle = Middle
			*** Raymond Guiteras' code to wrap notes	
			local MyNote = Question
			local l = length("`MyNote'")
			local b = ceil(`l'/$char)
			if `l' > $char {
				forv i = 1/`b' { 
					local lab`i': piece `i' $char of "`MyNote'", nobreak
					if `i'==1 {
						local MyNote2 `""`lab`i''""'
					}
					if `i'>=2 {
						local MyNote2 `"`MyNote2' "`lab`i''""'
					}
				}
			}
			else {
				local MyNote2 `""`MyNote'""'
			}
		restore
		sum maxH`m'`n'
		local max = r(mean)
		local mid = 1 + (`max'-1)/2
		twoway	(rspike hiH`m'`n' loH`m'`n' t 	if g==2, 	lcolor($c2)		msize(1))											///
				(rspike hiH`m'`n' loH`m'`n' t 	if g==1, 	lcolor($c1)		msize(1))											///
				(rspike hiH`m'`n' loH`m'`n' t 	if g==0, 	lcolor(gs12)	msize(1))											///
				(tsline H`m'`n'  	if g==2,   	lcolor($c2) 	lpattern(solid))												///
				(tsline H`m'`n'  	if g==1,   	lcolor($c1) 	lpattern(dash))												///
				(tsline H`m'`n'		if g==0,   	lcolor(gs12) 	lpattern(shortdash))											///
				(scatter H`m'`n' t 	if g==2, 	mcolor($c2) 	)																///
				(scatter H`m'`n' t 	if g==1, 	mcolor($c1) 	)																///
				(scatter H`m'`n' t 	if g==0,  	mcolor(gs12) 	),																///
				legend(pos($legendpos) ring(0) col(1) order(4 "Deliberation" 5 "Information" 6 "Control") size($fontsize) color($cf) region(style(none))) 	///
				xsc(/*noline*/ lcolor($cf) range(-.1 1.1))																					///
				ysc(/*noline*/ lcolor($cf) range(1 `max'))																					///
				xla(0 "Before" 1 "After", tlcolor($cf) /*notick*/ labsize($fontsize) labcolor($cf)) 											///
				yla(1 "`least'" `mid' "`middle'" `max' "`most'", tlcolor($cf) /*notick*/ nogrid angle(0) labsize($fontsize) labcolor($cf)) 	///
				xtitle("", size($fontsize) color($cf)) 																			///
				ytitle($leveltitle, size($fontsize) color($cf)) 																///
				graphregion(margin(small) lcolor($cb) fcolor($cb) ifcolor($cb) ilcolor($cb)) 									///
				plotregion(margin(medium) lcolor($cb) fcolor($cb) ifcolor($cb) ilcolor($cb))									///
				/*title("Roads", color($cf) justification(left) margin(small) span bexpand)*/									///
				subtitle(`MyNote2', color($cf) size($fontsize) justification(left) margin(small) span bexpand)					
		gr_edit 	.style.editstyle declared_ysize(6) editcopy
		gr_edit 	.style.editstyle declared_xsize(6) editcopy
		gr save  	"$figures/slopeline_H`m'`n'.gph", replace
		gr export 	"$figures/slopeline_H`m'`n'.pdf", as(pdf) replace	
	
		local ++j	
 }

di `""`MyNote'""'

exit
